#include "I2c.h"

void I2C2_Init (I2C_TypeDef* I2Cx)
{
	I2C_InitTypeDef I2C_InitStruct;
	I2C_DeInit(I2Cx);
	I2C_StructInit(&I2C_InitStruct);
	I2C_InitStruct.I2C_ClockSpeed = 200000;
	if (I2Cx==I2C1) RCC_APB1PeriphClockCmd(RCC_APB1Periph_I2C1, ENABLE);
			else RCC_APB1PeriphClockCmd(RCC_APB1Periph_I2C2, ENABLE);
	I2C_Cmd(I2Cx, ENABLE);
	I2C_Init(I2Cx, &I2C_InitStruct);

}


unsigned char I2C_Write_Byte (I2C_TypeDef* I2Cx, unsigned char i2c_address, unsigned char i2c_pointer, unsigned char data)
{
	while(I2C_GetFlagStatus(I2Cx, I2C_FLAG_BUSY));	
	I2C_GenerateSTART (I2Cx, ENABLE);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_MODE_SELECT));  
	I2C_Send7bitAddress(I2Cx, i2c_address, I2C_Direction_Transmitter);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_TRANSMITTER_MODE_SELECTED));
	I2C_SendData(I2Cx, i2c_pointer);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_TRANSMITTED));
	I2C_SendData(I2Cx, data);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_TRANSMITTED));
	I2C_GenerateSTOP(I2Cx, ENABLE);
	delay_ms(5);
	return 0;
}

unsigned char I2C_Read_Byte (I2C_TypeDef* I2Cx, unsigned char i2c_address, unsigned char i2c_pointer, unsigned char * data)
{
	I2C_GenerateSTART (I2Cx, ENABLE);					//START
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_MODE_SELECT));  
	
	I2C_Send7bitAddress(I2Cx, i2c_address, I2C_Direction_Transmitter);		//SEND ADDRESS
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_TRANSMITTER_MODE_SELECTED));
	
	I2C_SendData(I2Cx, i2c_pointer);						//SEND POINTER
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_TRANSMITTED));
	
	I2C_GenerateSTART (I2Cx, ENABLE);				//REPEAT START
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_MODE_SELECT));
	
	I2C_Send7bitAddress(I2Cx, i2c_address, I2C_Direction_Receiver);			//SEND ADDRESS READ
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_RECEIVED));
		
	*data=I2C_ReceiveData(I2Cx);								//READ DATA
	I2C_AcknowledgeConfig(I2Cx, DISABLE);
	I2C_GenerateSTOP(I2Cx, ENABLE);
	delay_ms(5);
	return 0;
}

unsigned char I2C_Read_Word (I2C_TypeDef* I2Cx, unsigned char i2c_address, unsigned char i2c_pointer, unsigned int * data)
{
	I2C_GenerateSTART (I2Cx, ENABLE);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_MODE_SELECT)); 
	
	I2C_Send7bitAddress(I2Cx, i2c_address, I2C_Direction_Transmitter);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_TRANSMITTER_MODE_SELECTED));
	
	I2C_SendData(I2Cx, i2c_pointer);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_TRANSMITTED));
	
	I2C_GenerateSTART (I2Cx, ENABLE);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_MODE_SELECT));
	
	I2C_Send7bitAddress(I2Cx, i2c_address, I2C_Direction_Receiver);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_RECEIVED));
	
	*data=I2C_ReceiveData(I2Cx);
	
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_RECEIVED));
	*data|=(I2C_ReceiveData(I2Cx)<<8);
	
	I2C_AcknowledgeConfig(I2Cx, DISABLE);
	I2C_GenerateSTOP(I2Cx, ENABLE);
	delay_ms(5);
	return 0;
}

unsigned char I2C_Read_Page (I2C_TypeDef* I2Cx, unsigned char i2c_address, unsigned char (*data)[HMC5883_Page_Size])
{
	unsigned char datcnt;
	
	I2C_GenerateSTART (I2Cx, ENABLE);					//START
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_MODE_SELECT));  
	
	I2C_Send7bitAddress(I2Cx, i2c_address, I2C_Direction_Transmitter);		//SEND ADDRESS
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_TRANSMITTER_MODE_SELECTED));
	
	I2C_SendData(I2Cx, 0);						//SEND POINTER TO ZERO!
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_TRANSMITTED));
	
	
	I2C_GenerateSTART (I2Cx, ENABLE);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_MODE_SELECT));
	
	I2C_Send7bitAddress(I2Cx, i2c_address, I2C_Direction_Receiver);
	
	I2C_AcknowledgeConfig(I2Cx, ENABLE);
	
	for(datcnt=0;datcnt!=(HMC5883_Page_Size-1);datcnt++)
	{	
		while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_RECEIVED));
		(*data)[datcnt]=I2C_ReceiveData(I2Cx);		
	}
	
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_RECEIVED));
	I2C_AcknowledgeConfig(I2Cx, DISABLE);
	(*data)[datcnt++]=I2C_ReceiveData(I2Cx);	

	
	I2C_GenerateSTOP(I2Cx, ENABLE);
	delay_ms(5);
	return 0;
}

unsigned char I2C_XYZ (I2C_TypeDef* I2Cx, unsigned char i2c_address, unsigned char (*data)[6])
{
	unsigned char datcnt;
	
	I2C_GenerateSTART (I2Cx, ENABLE);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_MODE_SELECT));
	
	I2C_Send7bitAddress(I2Cx, i2c_address, I2C_Direction_Receiver);
	
	I2C_AcknowledgeConfig(I2Cx, ENABLE);
	
	for(datcnt=0;datcnt!=5;datcnt++)
	{	
		while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_RECEIVED));
		(*data)[datcnt]=I2C_ReceiveData(I2Cx);		
	}
	
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_RECEIVED));
	I2C_AcknowledgeConfig(I2Cx, DISABLE);
	(*data)[datcnt++]=I2C_ReceiveData(I2Cx);	

	I2C_GenerateSTOP(I2Cx, ENABLE);
	delay_ms(5);
	return 0;
}

unsigned char I2C_Get_ID (I2C_TypeDef* I2Cx, unsigned char i2c_address, unsigned char (*data)[3])
{
	I2C_GenerateSTART (I2Cx, ENABLE);					//START
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_MODE_SELECT));  
	
	I2C_Send7bitAddress(I2Cx, i2c_address, I2C_Direction_Transmitter);		//SEND ADDRESS
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_TRANSMITTER_MODE_SELECTED));
	
	I2C_SendData(I2Cx, 10);						//SEND POINTER TO ID REG!
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_TRANSMITTED));
	
	
	I2C_GenerateSTART (I2Cx, ENABLE);
	while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_MODE_SELECT));
	
	I2C_Send7bitAddress(I2Cx, i2c_address, I2C_Direction_Receiver);
	
	I2C_AcknowledgeConfig(I2Cx, ENABLE);
	
		while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_RECEIVED));
		(*data)[0]=I2C_ReceiveData(I2Cx);		//read ID_A
	
		while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_RECEIVED));
		(*data)[1]=I2C_ReceiveData(I2Cx);		//read ID_B
			I2C_AcknowledgeConfig(I2Cx, DISABLE);
			
		while(!I2C_CheckEvent(I2Cx, I2C_EVENT_MASTER_BYTE_RECEIVED));
		(*data)[2]=I2C_ReceiveData(I2Cx);		//read ID_C
	
	I2C_GenerateSTOP(I2Cx, ENABLE);
	delay_ms(5);
	return 0;
}
